#include <fstream>
#include <vector>
#include <cmath>

#include <assert.h>

const double eps = 1E-10;

std::vector<double> axx, axy, ayy, bx, by, c;
std::vector<std::vector<int> > tP;
std::vector<int> dir, route, foundRoute, visited;
int n;

template <typename T> 
T sqr (const T& t)
{
    return t * t;
}

std::pair<double, double> ellipseXEdges(int ind)
{
  double ca = 4 * (axy[ind] * axy[ind] - ayy[ind] * axx[ind]);
  double cb = 4 * (axy[ind] * by[ind] - ayy[ind] * bx[ind]);
  double cc = by[ind] * by[ind] - 4 * ayy[ind] * c[ind];

  double D = cb * cb - 4 * ca * cc;

  assert(D > 0);

  std::pair<double, double> result = std::make_pair( (- cb - sqrt(D)) / (2 * ca), (- cb + sqrt(D)) / (2 * ca));
  if (result.first > result.second) std::swap(result.first, result.second);

  return result;
}

std::pair<double, double> ellipseSectionY(int ind, double x)
{
  double ca = ayy[ind];
  double cb = 2 * axy[ind]  * x + by[ind];
  double cc = c[ind] + axx[ind] * x * x + bx[ind] * x;

  double D = cb * cb - 4 * ca * cc;

  assert(D > 0);

  std::pair<double, double> result = std::make_pair( (- cb - sqrt(D)) / (2 * ca), (- cb + sqrt(D)) / (2 * ca));
  if (result.first > result.second) std::swap(result.first, result.second);

  return result;
}

double ellipseVal (int ind, double x, double y)
{
  return axx[ind] * x * x + 2 * axy[ind] * x * y + ayy[ind] * y * y + bx[ind] * x + by[ind] * y + c[ind];
}

double ellipseMin (int ind, double x, double yMin, double yMax)
{
  double rs = 1E10;

  while (yMax - yMin > eps)
  {
    double md1 = yMin + 1 * (yMax - yMin) / 3;
    double md2 = yMin + 2 * (yMax - yMin) / 3;

    double r1 = ellipseVal (ind, x, md1);
    double r2 = ellipseVal (ind, x, md2);

    if (r1 < r2)
      yMax = md2;
    else
      yMin = md1;

    rs = std::min(rs, r1);
    rs = std::min(rs, r2);
  }

  return rs;
}

bool doIntersect (int i1, int i2)
{
  std::pair<double, double> xBounds = ellipseXEdges(i1);
  std::pair<double, double> yBounds;
  double rs = 1E10;

  while (xBounds.second - xBounds.first > eps) 
  {
    double md1 = xBounds.first + 1 * (xBounds.second - xBounds.first) / 3;
    double md2 = xBounds.first + 2 * (xBounds.second - xBounds.first) / 3;

    yBounds = ellipseSectionY (i1, md1);
    double r1 = ellipseMin(i2, md1, yBounds.first, yBounds.second);

    yBounds = ellipseSectionY (i1, md2);
    double r2 = ellipseMin(i2, md2, yBounds.first, yBounds.second);

    if (r1 < r2)
      xBounds.second = md2;
    else
      xBounds.first = md1;

    rs = std::min(rs, r1);
    rs = std::min(rs, r2);
  }

  return rs < 0;
}

bool isTravelPossible (int s, int f)
{
  if (tP[s][f] == -1)
    tP[s][f] = dir[s] == dir[f] || !doIntersect(s, f);
  return tP[s][f];
}

bool enumRoutes (int d)
{
  if (d == n)
  {
    foundRoute = route;
    return true;
  }

  bool res = false;
  for (int i = 0; i < n && !res; ++i)
    if (!visited[i] && isTravelPossible(route[d - 1], i))
    {
      route[d] = i;
      visited[i] = true;
      res |= enumRoutes(d + 1);
      visited[i] = false;
    }
  return res;
}

int main (int argc, char** argv)
{
  std::fstream input ("input.txt", std::ios_base::in);
  std::fstream output ("output.txt", std::ios_base::out);

  input >> n;
  dir.resize(n); axx.resize(n); axy.resize(n); ayy.resize(n); bx.resize(n); by.resize(n); c.resize(n);

  tP.resize(n); route.resize(n);
  for (int i = 0; i < n; ++i)
  {
      tP[i].resize(n);
      for (int j = 0; j < n; ++j)
          tP[i][j] = -1;
  }
  for (int i = 0; i < n; ++i)
  {
      double tx1, ty1, tx2, ty2, tc;
      input >> tx1 >> ty1 >> tx2 >> ty2 >> tc >> dir[i];

      double ds = (sqr(tx2 - tx1) + sqr(ty2 - ty1)) / 4;
      double ts = sqr(tc) / 4;

      double alpha = - atan2(1.0 * ty2 - ty1, 1.0 * tx2 - tx1);
      double taxx = sqr(cos(alpha)) / ts + sqr(sin(alpha)) / (ts - ds);
      double taxy = - cos(alpha) * sin(alpha) / ts + cos(alpha) * sin(alpha) / (ts - ds);
      double tayy = sqr(sin(alpha)) / ts + sqr(cos(alpha)) / (ts - ds);

      axx[i] = taxx;
      axy[i] = taxy;
      ayy[i] = tayy;

      double centX = - 0.5 * (tx1 + tx2);
      double centY = - 0.5 * (ty1 + ty2);
      bx[i] = 2 * taxx * centX + 2 * taxy * centY;
      by[i] = 2 * tayy * centY + 2 * taxy * centX;

      c[i] = taxx * sqr(centX) + 2 * taxy * centX * centY + tayy * sqr(centY) - 1;
  }

  route.resize(n);
  visited.resize(n);
  route[0] = 0;
  visited[0] = true;
  enumRoutes (1);

  if (!foundRoute.empty())
      for (int i = 0; i < n; ++i)
          output << foundRoute[i] + 1 << " ";
  else
      output << -1;

  return 0;
}